@@ -10,10 +10,6 @@ from shutil import copyfile
 import numpy as np
 
 from PIL import Image
-from skimage import img_as_ubyte
-from skimage.measure import regionprops
-from skimage.segmentation import mark_boundaries
-from pycocotools import mask
 
 from .utils import get_semantic_bitmap
 
@@ -121,134 +117,12 @@ def get_bbox(binary_mask):
         return False
 
 
-def export_coco_panoptic(dataset, export_folder):
-    # Create export folder
-    # export_folder = os.path.join(export_folder, dataset.dataset_identifier, dataset.release['name'])
-    os.makedirs(export_folder, exist_ok=True)
-    
-    # INFO
-    info = {
-        'description': dataset.release['dataset']['name'],
-        'version':  dataset.release['name'],
-        # 'year': '2021'
-    }
-    
-    # CATEGORIES    
-    categories = []
-    for i, category in enumerate(dataset.categories):
-        color = category['color'] if 'color' in category else get_color(i)
-        isthing = int(category['has_instances']) if 'has_instances' in category else 0
-
-        categories.append({
-            'id': category['id'],
-            'name': category['name'],
-            'color': color,
-            'isthing': isthing
-        })
-    # print(categories)
-
-    categories_dict = {category['id']: category for category in categories}
-    id_generator = IdGenerator(categories_dict)
-        
-    # IMAGES AND ANNOTATIONS
-    images = []
-    annotations = []
-    for i in tqdm(range(len(dataset))):
-        sample = dataset[i]
-
-        if sample['annotations'] is None:
-            continue
-        
-        # Images
-        image_id = i+1
-        images.append({        
-            'id': image_id,
-            'file_name': sample['file_name'],
-            'height': sample['image'].size[1],
-            'width': sample['image'].size[0],
-        })
-        
-        # Annotations
-        panoptic_label = np.zeros((sample['image'].size[1], sample['image'].size[0], 3), np.uint8)
-        
-        segments_info = []
-        for instance in sample['annotations']:
-            category_id = instance['category_id']
-                
-            instance_id, color = id_generator.get_id_and_color(category_id)
-            
-            # Read the instance mask
-            instance_mask = np.array(sample['segmentation_bitmap'], np.uint32) == instance['id']
-            panoptic_label[instance_mask] = color
-            y0, x0, y1, x1 = get_bbox(instance_mask)
-            rle = mask.encode(np.array(instance_mask[:,:,None], dtype=np.uint8, order='F'))[0] # https://github.com/matterport/Mask_RCNN/issues/387#issuecomment-522671380
-            area = int(mask.area(rle))
-            
-            info = {
-                'id': instance_id,
-                'category_id': category_id,
-                'bbox': [x0, y0, x1-x0, y1-y0],
-                'area': area,
-                'iscrowd': 0
-            }
-
-            segments_info.append(info)
-            
-        file_name = os.path.splitext(os.path.basename(sample['name']))[0]
-        label_file_name = '{}_label_{}_coco-panoptic.png'.format(file_name, dataset.labelset)
-        annotations.append({
-            'segments_info': segments_info,
-            'file_name': label_file_name,
-            'image_id': image_id,
-        })        
-
-        # # Image
-        # image = sample['image']
-        # export_file = os.path.join(label_export_folder, '{}.png'.format(file_name))
-        # image.save(export_file)
-            
-        # # Instance png
-        # instance_label = sample['segmentation_bitmap']
-        # export_file = os.path.join(label_export_folder, '{}_gt_instance.png'.format(file_name))
-        # instance_label.save(export_file)
-        
-        # # Colored instance png
-        # instance_label_colored = colorize(np.uint8(instance_label))
-        # export_file = os.path.join(label_export_folder, '{}_gt_instance_colored.png'.format(file_name))
-        # Image.fromarray(img_as_ubyte(instance_label_colored)).save(export_file)
-        
-        # Panoptic png
-        export_file = os.path.join(dataset.image_dir, label_file_name)
-        Image.fromarray(panoptic_label).save(export_file)
-        
-        # # Semantic png
-        # semantic_label = get_semantic_bitmap(instance_label, sample['annotations'])
-        # export_file = os.path.join(label_export_folder, '{}_gt_semantic.png'.format(file_name))
-        # Image.fromarray(img_as_ubyte(semantic_label)).save(export_file)
-        
-        # # Colored semantic png
-        # semantic_label_colored = colorize(np.uint8(semantic_label), colormap=[c['color'] for c in categories])
-        # export_file = os.path.join(label_export_folder, '{}_gt_semantic_colored.png'.format(file_name))
-        # Image.fromarray(img_as_ubyte(semantic_label_colored)).save(export_file)
-    
-    # PUT EVERYTHING TOGETHER
-    json_data = {
-        'info': info,
-        'categories': categories,
-        'images': images,
-        'annotations': annotations    
-    }
-
-    # WRITE JSON TO FILE
-    file_name = os.path.join(export_folder, 'export_{}_{}.json'.format(dataset.dataset_identifier, dataset.release['name']))
-    with open(file_name, 'w') as f:
-        json.dump(json_data, f)
-
-    print('Exported to {}. Images and labels in {}'.format(file_name, dataset.image_dir))
-    return file_name, dataset.image_dir
-
-
 def export_coco_instance(dataset, export_folder):
+    # from skimage import img_as_ubyte
+    from skimage.measure import regionprops
+    # from skimage.segmentation import mark_boundaries
+    from pycocotools import mask
+
     # Create export folder
     # export_folder = os.path.join(export_folder, dataset.dataset_identifier, dataset.release['name'])
     os.makedirs(export_folder, exist_ok=True)
@@ -360,7 +234,7 @@ def export_coco_instance(dataset, export_folder):
     #     'segment_info': [] # Only in Panoptic annotations
     }
 
-    file_name = os.path.join(export_folder, 'export_{}_{}.json'.format(dataset.dataset_identifier, dataset.release['name']))
+    file_name = os.path.join(export_folder, 'export_coco-instance_{}_{}.json'.format(dataset.dataset_identifier, dataset.release['name']))
     with open(file_name, 'w') as f:
         json.dump(json_data, f)
 
@@ -368,6 +242,202 @@ def export_coco_instance(dataset, export_folder):
     return file_name, dataset.image_dir
 
 
+
+def export_coco_panoptic(dataset, export_folder):
+    # from skimage import img_as_ubyte
+    from skimage.measure import regionprops
+    # from skimage.segmentation import mark_boundaries
+    # from pycocotools import mask
+
+    # Create export folder
+    # export_folder = os.path.join(export_folder, dataset.dataset_identifier, dataset.release['name'])
+    os.makedirs(export_folder, exist_ok=True)
+    
+    # INFO
+    info = {
+        'description': dataset.release['dataset']['name'],
+        'version':  dataset.release['name'],
+        # 'year': '2021'
+    }
+    
+    # CATEGORIES    
+    categories = []
+    for i, category in enumerate(dataset.categories):
+        color = category['color'] if 'color' in category else get_color(i)
+        isthing = int(category['has_instances']) if 'has_instances' in category else 0
+
+        categories.append({
+            'id': category['id'],
+            'name': category['name'],
+            'color': color,
+            'isthing': isthing
+        })
+    # print(categories)
+
+    categories_dict = {category['id']: category for category in categories}
+    id_generator = IdGenerator(categories_dict)
+        
+    # IMAGES AND ANNOTATIONS
+    images = []
+    annotations = []
+    for i in tqdm(range(len(dataset))):
+        sample = dataset[i]
+
+        if sample['annotations'] is None:
+            continue
+        
+        # Images
+        image_id = i+1
+        images.append({        
+            'id': image_id,
+            'file_name': sample['file_name'],
+            'height': sample['image'].size[1],
+            'width': sample['image'].size[0],
+        })
+        
+        # Annotations
+        panoptic_label = np.zeros((sample['segmentation_bitmap'].size[1], sample['segmentation_bitmap'].size[0], 3), np.uint8)
+        
+        segments_info = []
+        for instance in sample['annotations']:
+            category_id = instance['category_id']
+                
+            instance_id, color = id_generator.get_id_and_color(category_id)
+            
+            # Read the instance mask
+            instance_mask = np.array(sample['segmentation_bitmap'], np.uint32) == instance['id']
+            panoptic_label[instance_mask] = color
+            y0, x0, y1, x1 = get_bbox(instance_mask)
+            rle = mask.encode(np.array(instance_mask[:,:,None], dtype=np.uint8, order='F'))[0] # https://github.com/matterport/Mask_RCNN/issues/387#issuecomment-522671380
+            area = int(mask.area(rle))
+
+            segments_info.append({
+                'id': instance_id,
+                'category_id': category_id,
+                'bbox': [x0, y0, x1-x0, y1-y0],
+                'area': area,
+                'iscrowd': 0
+            })
+            
+        file_name = os.path.splitext(os.path.basename(sample['name']))[0]
+        label_file_name = '{}_label_{}_coco-panoptic.png'.format(file_name, dataset.labelset)
+        annotations.append({
+            'segments_info': segments_info,
+            'file_name': label_file_name,
+            'image_id': image_id,
+        })        
+
+        # # Image
+        # image = sample['image']
+        # export_file = os.path.join(label_export_folder, '{}.png'.format(file_name))
+        # image.save(export_file)
+            
+        # # Instance png
+        # instance_label = sample['segmentation_bitmap']
+        # export_file = os.path.join(dataset.image_dir, '{}_label_{}_instance.png'.format(file_name, dataset.labelset))
+        # instance_label.save(export_file)
+        
+        # # Colored instance png
+        # instance_label_colored = colorize(np.uint8(instance_label))
+        # export_file = os.path.join(dataset.image_dir, '{}_label{}_instance_colored.png'.format(file_name, dataset.labelset))
+        # Image.fromarray(img_as_ubyte(instance_label_colored)).save(export_file)
+        
+        # Panoptic png
+        export_file = os.path.join(dataset.image_dir, label_file_name)
+        Image.fromarray(panoptic_label).save(export_file)
+        
+        # # Semantic png
+        # semantic_label = get_semantic_bitmap(instance_label, sample['annotations'])
+        # export_file = os.path.join(dataset.image_dir, '{}_label_{}_semantic.png'.format(file_name, dataset.labelset))
+        # Image.fromarray(img_as_ubyte(semantic_label)).save(export_file)
+        
+        # # Colored semantic png
+        # semantic_label_colored = colorize(np.uint8(semantic_label), colormap=[c['color'] for c in categories])
+        # export_file = os.path.join(dataset.image_dir, '{}_label_{}_semantic_colored.png'.format(file_name, dataset.labelset))
+        # Image.fromarray(img_as_ubyte(semantic_label_colored)).save(export_file)
+    
+    # PUT EVERYTHING TOGETHER
+    json_data = {
+        'info': info,
+        'categories': categories,
+        'images': images,
+        'annotations': annotations    
+    }
+
+    # WRITE JSON TO FILE
+    file_name = os.path.join(export_folder, 'export_coco-panoptic_{}_{}.json'.format(dataset.dataset_identifier, dataset.release['name']))
+    with open(file_name, 'w') as f:
+        json.dump(json_data, f)
+
+    print('Exported to {}. Images and labels in {}'.format(file_name, dataset.image_dir))
+    return file_name, dataset.image_dir
+
+
+def export_image(dataset, export_format, export_folder):
+    from skimage import img_as_ubyte
+
+    # Create export folder
+    # export_folder = os.path.join(export_folder, dataset.dataset_identifier, dataset.release['name'])
+    os.makedirs(export_folder, exist_ok=True)
+    
+    # CATEGORIES    
+    categories = []
+    for i, category in enumerate(dataset.categories):
+        color = category['color'] if 'color' in category else get_color(i)
+        isthing = int(category['has_instances']) if 'has_instances' in category else 0
+
+        categories.append({
+            'id': category['id'],
+            'name': category['name'],
+            'color': color,
+            'isthing': isthing
+        })
+
+    for i in tqdm(range(len(dataset))):
+        sample = dataset[i]
+
+        if sample['annotations'] is None:
+            continue
+
+        file_name = os.path.splitext(os.path.basename(sample['name']))[0]
+
+        # # Image
+        # image = sample['image']
+        # export_file = os.path.join(label_export_folder, '{}.png'.format(file_name))
+        # image.save(export_file)
+
+        if export_format == 'instance':
+            # Instance png
+            instance_label = sample['segmentation_bitmap']
+            export_file = os.path.join(dataset.image_dir, '{}_label_{}_instance.png'.format(file_name, dataset.labelset))
+            instance_label.save(export_file)
+
+        elif export_format == 'instance-color':
+            # Colored instance png
+            instance_label = sample['segmentation_bitmap']
+            instance_label_colored = colorize(np.uint8(instance_label))
+            export_file = os.path.join(dataset.image_dir, '{}_label{}_instance_colored.png'.format(file_name, dataset.labelset))
+            Image.fromarray(img_as_ubyte(instance_label_colored)).save(export_file)
+
+        elif export_format == 'semantic':
+            # Semantic png
+            instance_label = sample['segmentation_bitmap']
+            semantic_label = get_semantic_bitmap(instance_label, sample['annotations'])
+            export_file = os.path.join(dataset.image_dir, '{}_label_{}_semantic.png'.format(file_name, dataset.labelset))
+            Image.fromarray(img_as_ubyte(semantic_label)).save(export_file)
+
+        elif export_format == 'semantic-color':
+            # Colored semantic png
+            instance_label = sample['segmentation_bitmap']
+            semantic_label = get_semantic_bitmap(instance_label, sample['annotations'])
+            semantic_label_colored = colorize(np.uint8(semantic_label), colormap=[c['color'] for c in categories])
+            export_file = os.path.join(dataset.image_dir, '{}_label_{}_semantic_colored.png'.format(file_name, dataset.labelset))
+            Image.fromarray(img_as_ubyte(semantic_label_colored)).save(export_file)
+
+    print('Exported to {}'.format(dataset.image_dir))
+    return dataset.image_dir
+
+
 def export_yolo(dataset, export_folder):
     if dataset.task_type != 'bboxes':
         print('You can only export bounding box datasets to YOLO format.')
